@@ -10,7 +10,7 @@ def swish(x):
     return x * torch.sigmoid(x)
 
 def gelu(x):
-    """ 
+    """
     """
     return x * 0.5 * (1.0 + torch.erf(x / math.sqrt(2.0)))
 
@@ -19,6 +19,8 @@ def mish(x):
 
 ACT2FN = {"gelu": gelu, "relu": torch.nn.functional.relu, "swish": swish, "mish": mish}
 
+
+
 class BertConfig(object):
     
     def __init__(
@@ -50,7 +52,6 @@ class BertConfig(object):
         self.initializer_range = initializer_range
         self.layer_norm_eps = layer_norm_eps
 
-
 class BertLayerNorm(nn.Module):
     """LayerNorm层, 见Transformer(一), 讲编码器(encoder)的第3部分"""
     def __init__(self, hidden_size, eps=1e-12, conditional=False):
@@ -345,15 +346,6 @@ class BertLMPredictionHead(nn.Module):
         return hidden_states
 
 
-class BertOnlyMLMHead(nn.Module):
-    def __init__(self, config):
-        super().__init__()
-        self.predictions = BertLMPredictionHead(config)
-
-    def forward(self, sequence_output):
-        prediction_scores = self.predictions(sequence_output)
-        return prediction_scores
-
 
 class BertOnlyNSPHead(nn.Module):
     def __init__(self, config):
